Learn R Programming

onadata (version 0.1)

schoolfriends_edgelist: Schoolfriends network edgelist

Description

Edgelist of network of schoolfriends in a French high school

Usage

schoolfriends_edgelist

Arguments

Format

A dataframe with 2105 rows and 3 variables:

from

Person ID

to

Person ID

type

Whether the friendship is a known Facebook connection or if it was reported by from person

Examples

Run this code
# NOT RUN {
schoolfriends_edgelist
# }

Run the code above in your browser using DataLab