Learn R Programming

onadata (version 0.1)

workfrance_edgelist: Workplace network edgelist

Description

Edgelist of network of interactions between people in a French office building based on location sensor technology

Usage

workfrance_edgelist

Arguments

Format

A dataframe with 932 rows and 3 variables:

from

Person ID

to

Person ID

mins

Number of minutes spent co-located

Examples

Run this code
# NOT RUN {
workfrance_edgelist
# }

Run the code above in your browser using DataLab