powered by
Edgelist of network of schoolfriends in a French high school
schoolfriends_edgelist
A dataframe with 2105 rows and 3 variables:
Person ID
Whether the friendship is a known Facebook connection or if it was reported by from person
from
# NOT RUN { schoolfriends_edgelist # }
Run the code above in your browser using DataLab