powered by
Edgelist of network of interactions between people in a French office building based on location sensor technology
workfrance_edgelist
A dataframe with 932 rows and 3 variables:
Person ID
Number of minutes spent co-located
# NOT RUN { workfrance_edgelist # }
Run the code above in your browser using DataLab